// Load and exchange library for MC121.06
// Board settings

#include "mc12106load.h"

#define VENDOR_ID "2c6a"

#define STM_PRODUCT_ID "0005"
#define NM_PRODUCT_ID  "0006"

// Commands to STM
const unsigned char STM_GET_ID       = 0x31;
const unsigned char STM_SWITCH_TO_NM = 0x34;

// Response from STM
const unsigned char STM_RESPONSE = 0xA5;

const unsigned int CORES_COUNT = 2;

const unsigned int BOARD_MAGIC_CODE_VAL = 0x10612106;
const unsigned int PROCESSOR_MAGIC_CODE_VAL = 0x64076407;

#define COMMON_BOARD_LOCK_FILE "/var/tmp/mc12106_common_board_lock"
#define INDIVIDUAL_BOARD_LOCK_FILE_PREFIX "/var/tmp/"

// Memory banks

const PL_Addr C0_IMU_BEGIN          = 0x00000000;
const PL_Addr C0_IMU_BEGIN_USER     = 0x00000200;
const PL_Addr C0_IMU_END            = 0x00040000;

const PL_Addr C1_IMU_BEGIN          = 0x00000000;
const PL_Addr C1_IMU_BEGIN_USER     = 0x00000200;
const PL_Addr C1_IMU_END            = 0x00020000;

const PL_Addr C0_IMU_DUB_BEGIN      = 0x00040000;
const PL_Addr C0_IMU_DUB_BEGIN_USER = 0x00040200;
const PL_Addr C0_IMU_DUB_END        = 0x00080000;

const PL_Addr C1_IMU_DUB_BEGIN      = 0x00080000;
const PL_Addr C1_IMU_DUB_BEGIN_USER = 0x00080200;
const PL_Addr C1_IMU_DUB_END        = 0x000A0000;

const PL_Addr SHMEM_BEGIN           = 0x000A0000;
const PL_Addr SHMEM_BEGIN_USER      = 0x000A8000;
const PL_Addr SHMEM_END             = 0x000C0000;

const PL_Addr USB_BEGIN             = 0x10000000;
const PL_Addr USB_END               = 0x10010000;

const PL_Addr MDMACapb_BEGIN        = 0x10010000;
const PL_Addr MDMACapb_END          = 0x10010400;

const PL_Addr EMIC_BEGIN            = 0x10020000;
const PL_Addr EMIC_END              = 0x10020400;

const PL_Addr PER_BEGIN             = 0x10030000;
const PL_Addr PER_END               = 0x10034000;

const PL_Addr EMI_BEGIN             = 0x20000000;
const PL_Addr EMI_END               = 0x28000000;

// Commands to loader
const __u32 READ_MEM    = 0x00000001;
const __u32 WRITE_MEM   = 0x00000002;
const __u32 RUN_PROGRAM = 0x00000003;
const __u32 NM_PWR_OFF  = 0x00000004;

// Loader addresses

const PL_Addr LOADER_ADDR_BASE         = 0x160;

const PL_Addr STATUS_WORD_OFFSET  = 0x0;
const PL_Addr RETURN_VALUE_OFFSET = 0x1;
const PL_Addr PSEUDO_INT_OFFSET   = 0x2;

const PL_Addr FIRMWARE_VERSION_BASE    = 0x170;

const PL_Addr MAJOR_OFFSET = 0x0;
const PL_Addr MINOR_OFFSET = 0x1;

const PL_Addr BOARD_SERIAL_NUMBER_ADDR = 0x172;

// Loader flags
const PL_Word PROGRAM_STARTED = 0x1;
const PL_Word PROGRAM_STOPPED = PROGRAM_FINISHED; // Defined in interface header

// Barrier synchronization

const PL_Word NC_SYNC_FLAG = 0x1;

const PL_Addr SYNC_ADDR_BASE = LOADER_ADDR_BASE + 0x8;

const PL_Addr SYNC_TO_PC_BASE   = SYNC_ADDR_BASE + 0x0;
const PL_Addr SYNC_FROM_PC_BASE = SYNC_ADDR_BASE + 0x4;

const PL_Addr SYNC_FLAG_OFFSET  = 0x0;
const PL_Addr SYNC_VALUE_OFFSET = 0x1;
const PL_Addr SYNC_ADDR_OFFSET  = 0x2;
const PL_Addr SYNC_LEN_OFFSET   = 0x3;
