// Load and exchange library for MC121.06
// Internal functions

#ifndef __LIBLOAD_INT__H__
#define __LIBLOAD_INT__H__

#include <termios.h>
#include <unistd.h>
#include <limits.h>

/*#define USE_SYNC_AFTER_WRITE*/

#ifdef DBG
#define PL_DBG(fmt, ...) printf("%s:%d:%s: " fmt "\n", __FILE__, __LINE__, __FUNCTION__, ##__VA_ARGS__);
#else
#define	PL_DBG(fmt, ...);
#endif // DBG

// For synchronization access to LibLoad
#define LOCK_LL pthread_mutex_lock(&LL_mutex);
#define UNLOCK_LL pthread_mutex_unlock(&LL_mutex);

// Board descriptor
struct PL_Board
{
	unsigned int Magic_code;
	__u32 Board_ID;
	unsigned int Count_opened_PL_Access;
	int hCom_port;
	volatile long Com_port_in_use;
	int hIndividual_lock_file;
	unsigned int Count_working_functions;

	PL_Board(const char *pcCommPort);
	~PL_Board();

	int Get_board_id();
	int Switch_to_stm_if_no_more_used_and_close_com_port();
	int Capture_port();
	int Release_port();
	int Send_command(__u32 cmd, __u32 param1, __u32 param2, __u32 param3);
};

// Processor descriptor
struct PL_Access
{
	unsigned int Magic_code;
	PL_Board *board;
	unsigned int processorNo;
	unsigned int Count_working_functions;
	int Sync_cancel;
	int Sync_in_progress;

	PL_Access(unsigned int index, PL_Board *brd);
	~PL_Access();

	int Read(PL_Word *buf, PL_Addr addr, __u32 size);
	int Write(PL_Word *buf, PL_Addr addr, __u32 size);
	int Write1(PL_Word addr, PL_Word val);
};

int Capture_common_boards_lock();
int Release_common_boards_lock(int fd);
int Enum_boards(const char *product_id, PL_board_identification *board_identification, unsigned int *count, bool *com_port_found, char *com_port_name);
int Read_from_com_port(int fd, char *buf, size_t count); // In bytes
int Send_command_to_stm(const char *com_port_name, unsigned char command, __u32 *response);
int Get_nm_id(const char *nm_com_port_name, __u32 *nm_id);
int Check_board(PL_Board *board);
int Check_and_capture_board(PL_Board *board);
void Release_board(PL_Board *board);
int Check_access(PL_Access *access);
int Check_and_capture_access(PL_Access *access);
void Release_access(PL_Access *access);
int Check_and_capture_access_for_sync(PL_Access *access);
void Release_access_for_sync(PL_Access *access);
int Check_mem_ranges(unsigned int procNo, PL_Addr addr, PL_Word len, int RW);

#endif // __LIBLOAD_INT__H__
